pub struct Time(pub DateTime<Utc>);Expand description
Custom time type that wraps chrono::DateTime and provides custom JSON serialization matching the format expected by the REST API.
Tuple Fields
0: DateTime<Utc>Implementations
Sourceimpl Time
impl Time
Sourcepub fn from_unix(unix: i64, usec: i64) -> Option<Self>
pub fn from_unix(unix: i64, usec: i64) -> Option<Self>
Create a Time from unix timestamp and microseconds.
Returns None if the resulting timestamp is out of range.
Sourcepub fn unix_micro(&self) -> i64
pub fn unix_micro(&self) -> i64
Get the timestamp in microseconds
Sourcepub fn unix_milli(&self) -> i64
pub fn unix_milli(&self) -> i64
Get the timestamp in milliseconds